"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWindowSize = exports.usePrevious = exports.useMedia = exports.useMasonryColumns = exports.useContainerSizes = exports.useColumnWidths = exports.useColumnSizes = exports.UiFunction = exports.sumPropertyValue = exports.Size = exports.setStorageItem = exports.masonryQueries = exports.isBrowser = exports.getUniqueValues = exports.getUniqueListBy = exports.getUniqueList = exports.getStorageItem = exports.getQueryParam = exports.executeFetchAsync = exports.emptyGuid = exports.downloadObject = exports.defaultQueries = exports.createRequestInit = exports.copyToClipboard = void 0;
const react_1 = require("react");
const copyToClipboard = (textToCopy) => {
    if (navigator.clipboard && window.isSecureContext) {
        return navigator.clipboard.writeText(textToCopy);
    }
    else {
        let textArea = document.createElement("textarea");
        textArea.value = textToCopy;
        textArea.style.position = "fixed";
        textArea.style.left = "-999999px";
        textArea.style.top = "-999999px";
        document.body.appendChild(textArea);
        textArea.focus();
        textArea.select();
        return new Promise((res, rej) => {
            document.execCommand('copy') ? res() : rej();
            textArea.remove();
        });
    }
};
exports.copyToClipboard = copyToClipboard;
const createRequestInit = (data, bearerToken, method) => {
    const m = (method && method.length > 0)
        ? method
        : (data)
            ? 'POST'
            : 'GET';
    const headers = new Headers();
    headers.set('method', m);
    headers.set("Content-Type", 'application/json');
    headers.set("contentType", 'application/x-www-form-urlencoded');
    if (bearerToken && bearerToken.length > 0)
        headers.set('Authorization', 'Bearer ' + bearerToken);
    const requestInit = {
        method: m,
        headers,
    };
    if (data)
        requestInit.body = JSON.stringify(data);
    return requestInit;
};
exports.createRequestInit = createRequestInit;
exports.defaultQueries = [
    '(min-width: 1400px)', '(min-width: 1200px)', '(min-width: 992px)', '(min-width: 768px)', '(min-width: 576px)'
];
function downloadObject(o, fileName) {
    if (!exports.isBrowser)
        return;
    const dataStr = 'data:application/json;charset=utf-8,' +
        encodeURIComponent(JSON.stringify(o));
    const a = document.createElement('a');
    a.setAttribute('href', dataStr);
    a.setAttribute('download', fileName + '.json');
    document.body.appendChild(a);
    a.click();
    a.remove();
}
exports.downloadObject = downloadObject;
exports.emptyGuid = "00000000-0000-0000-0000-000000000000";
async function executeFetchAsync(url, data, bearerToken, method) {
    if (!exports.isBrowser)
        return;
    const requestInit = (0, exports.createRequestInit)(data, bearerToken, method);
    const result = await fetch(url, requestInit)
        .then(response => {
        if (response.ok) {
            return response.json();
        }
        else {
            console.warn(response.json());
            return null;
        }
    })
        .then(data => {
        if (!data) {
            console.warn("Connected, however no data from " + url);
            return null;
        }
        return data;
    })
        .catch(error => {
        console.warn(error);
        return null;
    });
    return result;
}
exports.executeFetchAsync = executeFetchAsync;
function getQueryParam(key, defaultValue) {
    if (!exports.isBrowser)
        return defaultValue || '';
    const urlParams = new URLSearchParams(window.location.search);
    for (const [k, v] of urlParams) {
        if (k.toLowerCase() === key.toLowerCase()) {
            return v;
        }
    }
    return defaultValue || '';
}
exports.getQueryParam = getQueryParam;
function getStorageItem(key) {
    let returnValue = null;
    if (exports.isBrowser) {
        const storageItem = window.localStorage.getItem(key);
        if (storageItem) {
            returnValue = JSON.parse(storageItem);
        }
    }
    return returnValue;
}
exports.getStorageItem = getStorageItem;
function getUniqueList(arr1, arr2) {
    const arr = (arr2) ? arr1.concat(arr2) : arr1;
    const result = [];
    const map = new Map();
    for (const item of arr) {
        if (!map.has(item)) {
            map.set(item, true);
            result.push(item);
        }
    }
    return result;
}
exports.getUniqueList = getUniqueList;
function getUniqueListBy(key, arr1, arr2) {
    const arr = (arr2) ? arr1.concat(arr2) : arr1;
    const result = [];
    const map = new Map();
    for (const item of arr) {
        if (!map.has(item[key])) {
            map.set(item[key], true);
            result.push(item);
        }
    }
    return result;
}
exports.getUniqueListBy = getUniqueListBy;
const getUniqueValues = (items, prop, removeEmpties = true) => {
    let returnValue = [...new Set(items.map((item) => item[prop]))];
    if (removeEmpties === true)
        returnValue = returnValue.filter(i => (i && i.length > 0));
    return returnValue;
};
exports.getUniqueValues = getUniqueValues;
exports.isBrowser = typeof window !== "undefined" && window;
exports.masonryQueries = [
    '(min-width: 1650px)', '(min-width: 1375px)', '(min-width: 1100px)', '(min-width: 825px)', '(min-width: 550px)'
];
function setStorageItem(key, obj) {
    const serializedObj = JSON.stringify(obj);
    window.localStorage.setItem(key, serializedObj);
}
exports.setStorageItem = setStorageItem;
var Size;
(function (Size) {
    Size[Size["sm"] = 0] = "sm";
    Size[Size["md"] = 1] = "md";
    Size[Size["lg"] = 2] = "lg";
    Size[Size["xl"] = 3] = "xl";
    Size[Size["xxl"] = 4] = "xxl";
    Size[Size["fluid"] = 5] = "fluid";
})(Size = exports.Size || (exports.Size = {}));
const sumPropertyValue = (items, prop) => items.reduce((a, b) => a + b[prop], 0);
exports.sumPropertyValue = sumPropertyValue;
var UiFunction;
(function (UiFunction) {
    UiFunction["Primary"] = "primary";
    UiFunction["Secondary"] = "secondary";
    UiFunction["Success"] = "success";
    UiFunction["Danger"] = "danger";
    UiFunction["Warning"] = "warning";
    UiFunction["Info"] = "info";
    UiFunction["Light"] = "light";
    UiFunction["Dark"] = "dark";
    UiFunction["Link"] = "link";
})(UiFunction = exports.UiFunction || (exports.UiFunction = {}));
function useColumnSizes(size, colSpan) {
    const collapsedStyle = {
        flexShrink: 0,
        flexBasis: 'auto'
    };
    const expandedStyle = {
        ...collapsedStyle,
        flexGrow: (colSpan > 0) ? '0' : '1',
        width: (colSpan > 0) ? (colSpan / 12) * 100 + '%' : 'auto',
    };
    switch (size) {
        case Size.fluid:
            return useMedia(exports.defaultQueries, [collapsedStyle, collapsedStyle, collapsedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.xxl:
            return useMedia(exports.defaultQueries, [expandedStyle, collapsedStyle, collapsedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.xl:
            return useMedia(exports.defaultQueries, [expandedStyle, expandedStyle, collapsedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.lg:
            return useMedia(exports.defaultQueries, [expandedStyle, expandedStyle, expandedStyle, collapsedStyle, collapsedStyle], collapsedStyle);
        case Size.md:
            return useMedia(exports.defaultQueries, [expandedStyle, expandedStyle, expandedStyle, expandedStyle, collapsedStyle], collapsedStyle);
        default:
            return useMedia(exports.defaultQueries, [expandedStyle, expandedStyle, expandedStyle, expandedStyle, expandedStyle], collapsedStyle);
    }
}
exports.useColumnSizes = useColumnSizes;
function useColumnWidths(width) {
    const queries = [];
    const values = [];
    for (let index = 10; index > 1; index--) {
        queries.push('(min-width: ' + index * width + 'px)');
        values.push(100 / index + '%');
    }
    return useMedia(queries, values, '100%');
}
exports.useColumnWidths = useColumnWidths;
function useContainerSizes(size) {
    switch (size) {
        case Size.fluid:
            return useMedia(exports.defaultQueries, ['100%', '100%', '100%', '100%', '100%'], '100%');
        case Size.xxl:
            return useMedia(exports.defaultQueries, ['1320px', '100%', '100%', '100%', '100%'], '100%');
        case Size.xl:
            return useMedia(exports.defaultQueries, ['1320px', '1140px', '100%', '100%', '100%'], '100%');
        case Size.lg:
            return useMedia(exports.defaultQueries, ['1320px', '1140px', '960px', '100%', '100%'], '100%');
        case Size.md:
            return useMedia(exports.defaultQueries, ['1320px', '1140px', '960px', '720px', '100%'], '100%');
        default:
            return useMedia(exports.defaultQueries, ['1320px', '1140px', '960px', '720px', '540px'], '100%');
    }
}
exports.useContainerSizes = useContainerSizes;
function useMasonryColumns() {
    return useMedia(exports.masonryQueries, [6, 5, 4, 3, 2], 1);
}
exports.useMasonryColumns = useMasonryColumns;
function useMedia(queries, values, defaultValue) {
    if (!exports.isBrowser)
        return defaultValue;
    const mediaQueryLists = queries.map((q) => window?.matchMedia(q));
    const getValue = () => {
        const index = mediaQueryLists.findIndex((mql) => mql.matches);
        return values?.[index] || defaultValue;
    };
    const [value, setValue] = (0, react_1.useState)(getValue);
    (0, react_1.useEffect)(() => {
        const handler = () => setValue(getValue);
        mediaQueryLists.forEach((mql) => mql.addEventListener("change", handler));
        return () => mediaQueryLists.forEach((mql) => mql.removeEventListener("change", handler));
    }, []);
    return value;
}
exports.useMedia = useMedia;
function usePrevious(value) {
    const ref = (0, react_1.useRef)();
    (0, react_1.useEffect)(() => void (ref.current = value), [value]);
    return ref.current;
}
exports.usePrevious = usePrevious;
function useWindowSize() {
    const [windowSize, setWindowSize] = (0, react_1.useState)({
        width: exports.isBrowser ? window.innerWidth : 1200,
        height: exports.isBrowser ? window.innerHeight : 800,
    });
    function changeWindowSize() {
        setWindowSize({ width: window.innerWidth, height: window.innerHeight });
    }
    (0, react_1.useEffect)(() => {
        window.addEventListener("resize", changeWindowSize);
        return () => { window.removeEventListener("resize", changeWindowSize); };
    }, []);
    return windowSize;
}
exports.useWindowSize = useWindowSize;
//# sourceMappingURL=index.js.map